@@ -29,11 +29,11 @@
  * 	ksCurrent() will tell you where it stopped.
  * @see ksFilter()
  */
-int ksForEach (KeySet *ks, int (*func) (Key *k))
+int ksForEach (KeySet * ks, int (*func) (Key * k))
 {
 	int rc = 0;
 	int ret = 0;
-	Key *current;
+	Key * current;
 
 	cursor_t cursor = ksGetCursor (ks);
 	ksRewind (ks);
@@ -43,7 +43,7 @@ int ksForEach (KeySet *ks, int (*func) (Key *k))
 		if (rc == -1) return -1;
 		ret += rc;
 	}
-	ksSetCursor(ks, cursor);
+	ksSetCursor (ks, cursor);
 	return ret;
 }
 
@@ -67,97 +67,112 @@ int ksForEach (KeySet *ks, int (*func) (Key *k))
  * 	be the problematic key.
  * @see ksForEach()
  **/
-int ksFilter (KeySet *result, KeySet *input, int (*filter) (Key *k))
+int ksFilter (KeySet * result, KeySet * input, int (*filter) (Key * k))
 {
 	int rc = 0;
 	int ret = 0;
-	Key *current;
+	Key * current;
 
 	cursor_t cursor = ksGetCursor (input);
 	ksRewind (input);
 	while ((current = ksNext (input)) != 0)
 	{
 		rc = filter (current);
-		if (rc == -1) return -1;
+		if (rc == -1)
+			return -1;
 		else if (rc != 0)
 		{
-			++ ret;
-			ksAppendKey(result, keyDup (current));
+			++ret;
+			ksAppendKey (result, keyDup (current));
 		}
 	}
-	ksSetCursor(input, cursor);
+	ksSetCursor (input, cursor);
 	return ret;
 }
 
 
-Key *global_a;
+Key * global_a;
 
-int add_string (Key *check) { return keySetString (check, "string"); }
-int add_comment (Key *check) { return keySetMeta (check, "comment", "comment"); }
-int has_a (Key *check) { return keyName(check)[5]=='a'; }
-int below_a (Key *check) { return keyIsBelow(global_a, check); }
-int direct_below_a (Key *check) { return keyIsDirectBelow(global_a, check); }
-
-int sum_helper (Key *check) { return atoi(keyValue(check)); }
-int below_30 (Key *check) { return atoi(keyValue(check))<30; }
-int find_80 (Key *check) { int n=atoi(keyValue(check)); return n>70?-1:1; }
-
-int main()
+int add_string (Key * check)
 {
-	KeySet *out;
-	KeySet *ks = ksNew (64,
-		keyNew ("user/a/1", KEY_END),
-		keyNew ("user/a/2", KEY_END),
-		keyNew ("user/a/b/1", KEY_END),
-		keyNew ("user/a/b/2", KEY_END),
-		keyNew ("user/ab/2", KEY_END),
-		keyNew ("user/b/1", KEY_END),
-		keyNew ("user/b/2", KEY_END),
-		KS_END);
-	KeySet *values = 0;
-	KeySet *values_below_30 = 0;
+	return keySetString (check, "string");
+}
+int add_comment (Key * check)
+{
+	return keySetMeta (check, "comment", "comment");
+}
+int has_a (Key * check)
+{
+	return keyName (check)[5] == 'a';
+}
+int below_a (Key * check)
+{
+	return keyIsBelow (global_a, check);
+}
+int direct_below_a (Key * check)
+{
+	return keyIsDirectBelow (global_a, check);
+}
+
+int sum_helper (Key * check)
+{
+	return atoi (keyValue (check));
+}
+int below_30 (Key * check)
+{
+	return atoi (keyValue (check)) < 30;
+}
+int find_80 (Key * check)
+{
+	int n = atoi (keyValue (check));
+	return n > 70 ? -1 : 1;
+}
+
+int main ()
+{
+	KeySet * out;
+	KeySet * ks = ksNew (64, keyNew ("user/a/1", KEY_END), keyNew ("user/a/2", KEY_END), keyNew ("user/a/b/1", KEY_END),
+			     keyNew ("user/a/b/2", KEY_END), keyNew ("user/ab/2", KEY_END), keyNew ("user/b/1", KEY_END),
+			     keyNew ("user/b/2", KEY_END), KS_END);
+	KeySet * values = 0;
+	KeySet * values_below_30 = 0;
 
 	global_a = keyNew ("user/a", KEY_END);
 
 	ksForEach (ks, add_string);
 	ksForEach (ks, add_comment);
 
-	out = ksNew(0, KS_END);
+	out = ksNew (0, KS_END);
 	ksFilter (out, ks, has_a);
 	ksDel (out);
 
-	out = ksNew(0, KS_END);
+	out = ksNew (0, KS_END);
 	ksFilter (out, ks, below_a);
 	ksDel (out);
 
-	out = ksNew(0, KS_END);
+	out = ksNew (0, KS_END);
 	ksFilter (out, ks, direct_below_a);
 	ksDel (out);
 
 	ksDel (ks);
-	keyDel (global_a); global_a = 0;
+	keyDel (global_a);
+	global_a = 0;
 
-	values = ksNew (64,
-		keyNew ("user/a", KEY_VALUE, "40", KEY_END),
-		keyNew ("user/b", KEY_VALUE, "20", KEY_END),
-		keyNew ("user/c", KEY_VALUE, "80", KEY_END),
-		keyNew ("user/d", KEY_VALUE, "24", KEY_END),
-		keyNew ("user/e", KEY_VALUE, "32", KEY_END),
-		keyNew ("user/f", KEY_VALUE, "12", KEY_END),
-		keyNew ("user/g", KEY_VALUE, "43", KEY_END),
-		KS_END);
+	values = ksNew (64, keyNew ("user/a", KEY_VALUE, "40", KEY_END), keyNew ("user/b", KEY_VALUE, "20", KEY_END),
+			keyNew ("user/c", KEY_VALUE, "80", KEY_END), keyNew ("user/d", KEY_VALUE, "24", KEY_END),
+			keyNew ("user/e", KEY_VALUE, "32", KEY_END), keyNew ("user/f", KEY_VALUE, "12", KEY_END),
+			keyNew ("user/g", KEY_VALUE, "43", KEY_END), KS_END);
 
 	/* add together */
 	ksForEach (values, sum_helper);
 
-	values_below_30 = ksNew(0, KS_END);
+	values_below_30 = ksNew (0, KS_END);
 	ksFilter (values_below_30, values, below_30);
 	ksForEach (values_below_30, sum_helper);
 
 	ksForEach (values, find_80);
-	ksCurrent (values); /* here is user/c */
+	ksCurrent (values);		      /* here is user/c */
 	ksLookupByName (values, "user/c", 0); /* should find the same */
 	ksDel (values);
 	ksDel (values_below_30);
 }
-
