@@ -8,44 +8,42 @@
 
 #include <kdb.h>
 #include <stdio.h>
-#include <string.h>
 #include <stdlib.h>
+#include <string.h>
 
-void printError(Key * key);
-void printWarnings(Key * key);
-void removeMetaData(Key * key, const char * searchfor);
+void printError (Key * key);
+void printWarnings (Key * key);
+void removeMetaData (Key * key, const char * searchfor);
 
-int main()
+int main ()
 {
 	KeySet * myConfig = ksNew (0, KS_END);
 	Key * key = keyNew ("/sw/MyApp", KEY_CASCADING_NAME, KEY_END);
 	KDB * handle = kdbOpen (key);
 
-	if (!handle)
-		printError(key);
+	if (!handle) printError (key);
 
 
-	printWarnings(key);
+	printWarnings (key);
 
-	if ( kdbGet(handle, myConfig, key) < 0)
-		printError(key);
+	if (kdbGet (handle, myConfig, key) < 0) printError (key);
 
 
-	printWarnings(key);
+	printWarnings (key);
 
 	keyDel (key);
 
-	//lookup
-	Key * result = ksLookupByName (myConfig,"/sw/MyApp/Tests/TestKey1", 0);
+	// lookup
+	Key * result = ksLookupByName (myConfig, "/sw/MyApp/Tests/TestKey1", 0);
 	if (!result)
-		printf("Key not found in KeySet\n");
+		printf ("Key not found in KeySet\n");
 	else
 	{
-		//do something with the key
-		const char * key_name = keyName(result);
-		const char * key_value = keyString(result);
-		const char * key_comment = keyString(keyGetMeta(result, "comment"));
-		printf("key: %s value: %s comment: %s\n", key_name, key_value, key_comment);
+		// do something with the key
+		const char * key_name = keyName (result);
+		const char * key_value = keyString (result);
+		const char * key_comment = keyString (keyGetMeta (result, "comment"));
+		printf ("key: %s value: %s comment: %s\n", key_name, key_value, key_comment);
 	}
 
 	ksDel (myConfig); // delete the in-memory configuration
@@ -53,7 +51,7 @@ int main()
 
 	// maybe you want kdbSet() myConfig here
 
-	kdbClose(handle, 0); // no more affairs with the key database.
+	kdbClose (handle, 0); // no more affairs with the key database.
 }
 
 
@@ -63,13 +61,12 @@ int main()
  * the Key returned by keyGetMeta(key,"error").
  * Or print all MetaData, by using the loop from removeMetaData ().
  */
-void printError(Key * key)
+void printError (Key * key)
 {
-	printf ("Error occurred: %s\n",
-			keyString(keyGetMeta (key,"error/description")));
+	printf ("Error occurred: %s\n", keyString (keyGetMeta (key, "error/description")));
 
 	/*remove error*/
-	removeMetaData(key,"error");
+	removeMetaData (key, "error");
 }
 
 
@@ -80,11 +77,11 @@ void printError(Key * key)
  * is the Warning number, starting at 00.
  * Or print all MetaData, by using the loop from removeMetaData ().
  */
-void printWarnings(Key * key)
+void printWarnings (Key * key)
 {
-	if (!keyGetMeta (key,"warnings")) return;
+	if (!keyGetMeta (key, "warnings")) return;
 	char * end;
-	int warn_count = strtol (keyString (keyGetMeta (key,"warnings")),&end,10);
+	int warn_count = strtol (keyString (keyGetMeta (key, "warnings")), &end, 10);
 	if (*end)
 	{
 		printf ("strtol error\n");
@@ -92,21 +89,22 @@ void printWarnings(Key * key)
 	}
 	int warn_iter = 0;
 
-	char buffer [sizeof("warnings/#00/description")];
+	char buffer[sizeof ("warnings/#00/description")];
 
-	do{
+	do
+	{
 		if (warn_iter < 10)
-			sprintf(&buffer[0],"warnings/#0%i/description",warn_iter);
+			sprintf (&buffer[0], "warnings/#0%i/description", warn_iter);
 		else
-			sprintf(&buffer[0],"warnings/#%i/description",warn_iter);
+			sprintf (&buffer[0], "warnings/#%i/description", warn_iter);
 
-		const Key * warnkey = keyGetMeta (key,buffer);
-		printf ("Warning occurred: %s\n",keyString (warnkey));
+		const Key * warnkey = keyGetMeta (key, buffer);
+		printf ("Warning occurred: %s\n", keyString (warnkey));
 		++warn_iter;
 	} while (warn_iter <= warn_count);
 
 	/*remove all warnings*/
-	removeMetaData(key,"warnings");
+	removeMetaData (key, "warnings");
 }
 
 
@@ -114,17 +112,16 @@ void printWarnings(Key * key)
  * and removes all MetaKeys starting with
  * searchfor.
  */
-void removeMetaData(Key * key, const char * searchfor)
+void removeMetaData (Key * key, const char * searchfor)
 {
 	const Key * iter_key;
 	keyRewindMeta (key);
-	while ((iter_key = keyNextMeta (key))!=0)
+	while ((iter_key = keyNextMeta (key)) != 0)
 	{
 		/*startsWith*/
 		if (strncmp (searchfor, keyName (iter_key), strlen (searchfor)) == 0)
 		{
-			if (keySetMeta (key,keyName (iter_key),0) != 0)
-				printf ("Error while deleting %s\n", searchfor);
+			if (keySetMeta (key, keyName (iter_key), 0) != 0) printf ("Error while deleting %s\n", searchfor);
 		}
 	}
 }
