@@ -8,6 +8,7 @@
  */
 
 #include <gtest/gtest.h>
+#include <kdbconfig.h>
 #include <kdbgetenv.h>
 
 namespace ckdb
@@ -22,14 +23,22 @@ TEST (GetEnv, SimpleFork)
 	setenv ("does-exist", "hello", 1);
 	ASSERT_NE (getenv ("does-exist"), static_cast<char *> (nullptr));
 	EXPECT_EQ (getenv ("does-exist"), std::string ("hello"));
+#if VERBOSE
 	pid_t f;
 	f = fork ();
-	// std::cerr << "FORK " << f << std::endl;
+	std::cerr << "FORK " << f << std::endl;
+#else
+	fork ();
+#endif
 	ASSERT_NE (getenv ("does-exist"), static_cast<char *> (nullptr));
 	EXPECT_EQ (getenv ("does-exist"), std::string ("hello"));
 
+#if VERBOSE
 	f = fork ();
-	// std::cerr << "FORK " << f << std::endl;
+	std::cerr << "FORK " << f << std::endl;
+#else
+	fork ();
+#endif
 	ASSERT_NE (getenv ("does-exist"), static_cast<char *> (nullptr));
 	EXPECT_EQ (getenv ("does-exist"), std::string ("hello"));
 	elektraClose ();
