@@ -94,6 +94,9 @@ private:
 	void removeProvided (std::vector<std::string> & needs) const;
 	void removeMetadata (std::set<std::string> & needsMetadata) const;
 
+protected:
+	KeySet backendConf;
+
 public:
 	explicit BackendBuilder (BackendBuilderInit const & bbi = BackendBuilderInit ());
 
@@ -144,9 +147,11 @@ public:
 	std::vector<std::string> resolveNeeds (bool addRecommends = true);
 
 	void recommendPlugin (std::string provider);
-	void resolveRecommends ();
 
 	void fillPlugins (BackendInterface & b) const;
+
+	void setBackendConfig (KeySet const & ks);
+	KeySet getBackendConfig ();
 };
 
 /**
@@ -168,8 +173,13 @@ public:
 class MountBackendBuilder : public MountBackendInterface, public BackendBuilder
 {
 	Key mountpoint;
-	KeySet backendConf;
+
+	/**
+	 * Contains the keys of system/elektra/mountpoints.
+	 * It is needed to detect if a mountpoint already exists.
+	 */
 	KeySet mountConf;
+
 	std::string configfile;
 
 public:
@@ -184,10 +194,6 @@ public:
 	std::string getMountpoint () const;
 
 	void setBackendConfig (KeySet const & ks);
-	KeySet getBackendConfig ()
-	{
-		return backendConf;
-	}
 
 	void useConfigFile (std::string file);
 	std::string getConfigFile () const;
