@@ -25,35 +25,35 @@ namespace tools
  *
  * @return an vector of information about mounted backends
  */
-Backends::BackendInfoVector Backends::getBackendInfo(KeySet mountConf)
+Backends::BackendInfoVector Backends::getBackendInfo (KeySet mountConf)
 {
 	std::vector<BackendInfo> ret;
 	Key rootKey (Backends::mountpointsPath, KEY_END);
 	Key cur;
 
-	mountConf.rewind();
-	while ((cur = mountConf.next()))
+	mountConf.rewind ();
+	while ((cur = mountConf.next ()))
 	{
-		if (cur.isDirectBelow(rootKey))
+		if (cur.isDirectBelow (rootKey))
 		{
 			BackendInfo bi;
 
-			Key path = mountConf.lookup (cur.getName() + "/config/path");
+			Key path = mountConf.lookup (cur.getName () + "/config/path");
 			if (path)
 			{
-				bi.path = path.getString();
+				bi.path = path.getString ();
 			}
-			Key mp = mountConf.lookup (cur.getName() + "/mountpoint");
+			Key mp = mountConf.lookup (cur.getName () + "/mountpoint");
 			if (mp)
 			{
-				bi.mountpoint = mp.getString();
+				bi.mountpoint = mp.getString ();
 			}
-			bi.name = cur.getBaseName();
+			bi.name = cur.getBaseName ();
 
-			ret.push_back(bi);
+			ret.push_back (bi);
 		}
 	}
-	return std::move(ret);
+	return ret;
 }
 
 /**
@@ -70,20 +70,20 @@ Backends::BackendInfoVector Backends::getBackendInfo(KeySet mountConf)
  * @return the found backend or an empty BackendInfo if nothing found
  *         (with empty strings)
  */
-BackendInfo Backends::findBackend(std::string const & mountPath, KeySet mountConf, bool verbose)
+BackendInfo Backends::findBackend (std::string const & mountPath, KeySet mountConf, bool verbose)
 {
 	BackendInfo ret;
-	if (mountPath.empty()) return ret;
+	if (mountPath.empty ()) return ret;
 
 	Backends::BackendInfoVector mtab = Backends::getBackendInfo (mountConf);
 
-	Key kmp(Backends::getBasePath(mountPath), KEY_END);
+	Key kmp (Backends::getBasePath (mountPath), KEY_END);
 
 	// search for proper mountname:
 	for (Backends::BackendInfoVector::const_iterator it = mtab.begin (); it != mtab.end (); ++it)
 	{
-		if (verbose) std::cout << "compare: " << it->mountpoint << " with " << kmp.getBaseName() << std::endl;
-		if (it->mountpoint == kmp.getBaseName())
+		if (verbose) std::cout << "compare: " << it->mountpoint << " with " << kmp.getBaseName () << std::endl;
+		if (it->mountpoint == kmp.getBaseName ())
 		{
 			return *it;
 		}
@@ -93,12 +93,12 @@ BackendInfo Backends::findBackend(std::string const & mountPath, KeySet mountCon
 	// May umount wrong things, so its done as extra step so that
 	// it will never happen if something desired is present.
 	std::string soldMountpoint = mountPath;
-	std::replace(soldMountpoint.begin(), soldMountpoint.end(), '_', '/');
-	Key koldMountpoint("user/" + soldMountpoint, KEY_END);
-	std::string omp = koldMountpoint.getName();
-	std::string oldMountpoint(omp.begin()+4, omp.end());
-	if (soldMountpoint.at(0) != '/') oldMountpoint.erase(0,1); // fix non-cascading
-	if (koldMountpoint.getName() == "user") oldMountpoint = "/"; // fix root
+	std::replace (soldMountpoint.begin (), soldMountpoint.end (), '_', '/');
+	Key koldMountpoint ("user/" + soldMountpoint, KEY_END);
+	std::string omp = koldMountpoint.getName ();
+	std::string oldMountpoint (omp.begin () + 4, omp.end ());
+	if (soldMountpoint.at (0) != '/') oldMountpoint.erase (0, 1); // fix non-cascading
+	if (koldMountpoint.getName () == "user") oldMountpoint = "/"; // fix root
 	for (Backends::BackendInfoVector::const_iterator it = mtab.begin (); it != mtab.end (); ++it)
 	{
 		if (verbose) std::cout << "fallback compare: " << it->mountpoint << " with " << oldMountpoint << std::endl;
@@ -120,14 +120,15 @@ BackendInfo Backends::findBackend(std::string const & mountPath, KeySet mountCon
  * @retval true if something was done
  * @retval false if nothing was done (but also no error)
  */
-bool Backends::umount(std::string const & mountPath, KeySet & mountConf)
+bool Backends::umount (std::string const & mountPath, KeySet & mountConf)
 {
-	BackendInfo bi = Backends::findBackend(mountPath, mountConf);
-	if (!bi.name.empty())
+	BackendInfo bi = Backends::findBackend (mountPath, mountConf);
+	if (!bi.name.empty ())
 	{
-		Key x(Backends::mountpointsPath, KEY_END);;
-		x.addBaseName(bi.name);
-		mountConf.cut(x);
+		Key x (Backends::mountpointsPath, KEY_END);
+		;
+		x.addBaseName (bi.name);
+		mountConf.cut (x);
 		return true;
 	}
 
@@ -142,19 +143,17 @@ bool Backends::umount(std::string const & mountPath, KeySet & mountConf)
  *
  * @return the properly prefixed and escaped name
  */
-std::string Backends::getBasePath(std::string mp)
+std::string Backends::getBasePath (std::string mp)
 {
-	Key k(Backends::mountpointsPath, KEY_END);
-	Key kmp(mp, KEY_CASCADING_NAME, KEY_END); // canonify name
-	k.addBaseName(kmp.getName()); // escape name
-	return k.getName();
+	Key k (Backends::mountpointsPath, KEY_END);
+	Key kmp (mp, KEY_CASCADING_NAME, KEY_END); // canonify name
+	k.addBaseName (kmp.getName ());		   // escape name
+	return k.getName ();
 }
 
 /**
  * @brief Below this path is the mountConf
  */
 const char * Backends::mountpointsPath = "system/elektra/mountpoints";
-
 }
-
 }
