@@ -21,16 +21,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/types.h>
 
 #include "conditionals.h"
 
 #define EPSILON 0.00001
 
-#if defined(__APPLE__)
-#define REGEX_FLAGS_CONDITION (REG_EXTENDED | REG_NEWLINE | REG_ENHANCED | REG_MINIMAL)
-#else
-#define REGEX_FLAGS_CONDITION (REG_EXTENDED | REG_NEWLINE)
-#endif
+#define REGEX_FLAGS_CONDITION (REG_EXTENDED)
 
 typedef enum {
 	EQU,
@@ -187,8 +184,8 @@ static int compareStrings (const char * s1, const char * s2, const Key * suffixL
 	return retval;
 }
 
-static CondResult evalCondition (const char * leftSide, Comparator cmpOp, const char * rightSide, const char * condition,
-				 const Key * suffixList, KeySet * ks, Key * parentKey)
+static CondResult evalCondition (const Key * curKey, const char * leftSide, Comparator cmpOp, const char * rightSide,
+				 const char * condition, const Key * suffixList, KeySet * ks, Key * parentKey)
 {
 	char * lookupName = NULL;
 	char * compareTo = NULL;
@@ -218,14 +215,26 @@ static CondResult evalCondition (const char * leftSide, Comparator cmpOp, const
 		else if (rightSide && elektraStrLen (rightSide) > 1)
 		{
 			// not a literal, it has to be a key
-			len = keyGetNameSize (parentKey) + elektraStrLen (rightSide);
+			if (rightSide[0] == '@')
+				len = keyGetNameSize (parentKey) + elektraStrLen (rightSide);
+			else if (!strncmp (rightSide, "..", 2) || (rightSide[0] == '.'))
+				len = keyGetNameSize (curKey) + elektraStrLen (rightSide);
+			else
+				len = elektraStrLen (rightSide);
+
 			if (elektraRealloc ((void **)&lookupName, len) < 0)
 			{
 				ELEKTRA_SET_ERROR (87, parentKey, "Out of memory");
 				result = ERROR;
 				goto Cleanup;
 			}
-			snprintf (lookupName, len, "%s/%s", keyName (parentKey), rightSide);
+			if (rightSide[0] == '@')
+				snprintf (lookupName, len, "%s/%s", keyName (parentKey), rightSide + 1);
+			else if (rightSide[0] == '.') // either starts with . or .., doesn't matter at this point
+				snprintf (lookupName, len, "%s/%s", keyName (curKey), rightSide);
+			else
+				snprintf (lookupName, len, "%s", rightSide);
+
 			key = ksLookupByName (ks, lookupName, 0);
 			if (!key)
 			{
@@ -246,15 +255,25 @@ static CondResult evalCondition (const char * leftSide, Comparator cmpOp, const
 			strcpy (compareTo, keyString (key));
 		}
 	}
+	if (leftSide[0] == '@')
+		len = keyGetNameSize (parentKey) + elektraStrLen (leftSide);
+	else if (!strncmp (leftSide, "..", 2) || (leftSide[0] == '.'))
+		len = keyGetNameSize (curKey) + elektraStrLen (leftSide);
+	else
+		len = elektraStrLen (leftSide);
 
-	len = keyGetNameSize (parentKey) + elektraStrLen (leftSide);
 	if (elektraRealloc ((void **)&lookupName, len) < 0)
 	{
 		ELEKTRA_SET_ERROR (87, parentKey, "Out of memory");
 		result = ERROR;
 		goto Cleanup;
 	}
-	snprintf (lookupName, len, "%s/%s", keyName (parentKey), leftSide);
+	if (leftSide[0] == '@')
+		snprintf (lookupName, len, "%s/%s", keyName (parentKey), leftSide + 1);
+	else if (leftSide[0] == '.') // either . or .., doesn't matter here
+		snprintf (lookupName, len, "%s/%s", keyName (curKey), leftSide);
+	else
+		snprintf (lookupName, len, "%s", leftSide);
 	key = ksLookupByName (ks, lookupName, 0);
 	if (cmpOp == NEX)
 	{
@@ -380,7 +399,7 @@ static char * condition2cmpOp (const char * condition, Comparator * cmpOp)
 	return opStr;
 }
 
-static CondResult parseSingleCondition (const char * condition, const Key * suffixList, KeySet * ks, Key * parentKey)
+static CondResult parseSingleCondition (const Key * key, const char * condition, const Key * suffixList, KeySet * ks, Key * parentKey)
 {
 	Comparator cmpOp;
 	char * opStr;
@@ -459,13 +478,13 @@ static CondResult parseSingleCondition (const char * condition, const Key * suff
 	CondResult ret;
 
 parseSingleEnd:
-	ret = evalCondition (leftSide, cmpOp, rightSide, condition, suffixList, ks, parentKey);
+	ret = evalCondition (key, leftSide, cmpOp, rightSide, condition, suffixList, ks, parentKey);
 	if (rightSide) elektraFree (rightSide);
 	elektraFree (leftSide);
 	return ret;
 }
 
-static const char * isAssign (char * expr, Key * parentKey, KeySet * ks)
+static const char * isAssign (Key * key, char * expr, Key * parentKey, KeySet * ks)
 {
 	char * firstPtr = expr + 1;
 	char * lastPtr = expr + elektraStrLen (expr) - 3;
@@ -475,26 +494,57 @@ static const char * isAssign (char * expr, Key * parentKey, KeySet * ks)
 		--lastPtr;
 	if (*firstPtr != '\'' || *lastPtr != '\'')
 	{
-		if (lastPtr <= firstPtr) return NULL;
+		if (lastPtr <= firstPtr)
+		{
+			ELEKTRA_SET_ERRORF (134, parentKey,
+					    "Invalid syntax: \"%s\". Check kdb info conditionals for additional information", expr);
+			return NULL;
+		}
 		*(lastPtr + 1) = '\0';
-		Key * lookupKey = keyDup (parentKey);
-		keyAddName (lookupKey, firstPtr);
+		Key * lookupKey;
+		if (*firstPtr == '@')
+		{
+			lookupKey = keyDup (parentKey);
+			++firstPtr;
+			keyAddName (lookupKey, firstPtr);
+		}
+		else if (!strncmp (firstPtr, "..", 2) || !strncmp (firstPtr, ".", 1))
+		{
+			lookupKey = keyDup (key);
+			keyAddName (lookupKey, firstPtr);
+		}
+		else
+		{
+			lookupKey = keyNew (firstPtr, KEY_END);
+		}
 		Key * assign = ksLookup (ks, lookupKey, KDB_O_NONE);
-		keyDel (lookupKey);
 		if (!assign)
 		{
+			ELEKTRA_SET_ERRORF (133, parentKey, "Key %s not found", keyName (lookupKey));
+			keyDel (lookupKey);
 			return NULL;
 		}
 		else
 		{
+			keyDel (lookupKey);
 			return keyString (assign);
 		}
 	}
 	else
 	{
-		if (firstPtr == lastPtr) return NULL;
+		if (firstPtr == lastPtr) // only one quote in the assign string, invalid syntax
+		{
+			ELEKTRA_SET_ERRORF (134, parentKey,
+					    "Invalid syntax: \"%s\". Check kdb info conditionals for additional information", expr);
+			return NULL;
+		}
 		char * nextMark = strchr (firstPtr + 1, '\'');
-		if (nextMark != lastPtr) return NULL;
+		if (nextMark != lastPtr) // more than two quotes, invalid syntax too
+		{
+			ELEKTRA_SET_ERRORF (134, parentKey,
+					    "Invalid syntax: \"%s\". Check kdb info conditionals for additional information", expr);
+			return NULL;
+		}
 		*lastPtr = '\0';
 		*firstPtr = '\0';
 		++firstPtr;
@@ -502,7 +552,7 @@ static const char * isAssign (char * expr, Key * parentKey, KeySet * ks)
 	}
 }
 
-static CondResult parseCondition (const char * condition, const Key * suffixList, KeySet * ks, Key * parentKey)
+static CondResult parseCondition (Key * key, const char * condition, const Key * suffixList, KeySet * ks, Key * parentKey)
 {
 	CondResult result = FALSE;
 	const char * regexString = "((\\(([^\\(\\)]*)\\)))";
@@ -540,7 +590,7 @@ static CondResult parseCondition (const char * condition, const Key * suffixList
 		char * singleCondition = elektraMalloc (endPos - startPos + 1);
 		strncpy (singleCondition, localCondition + startPos, endPos - startPos);
 		singleCondition[endPos - startPos] = '\0';
-		result = parseSingleCondition (singleCondition, suffixList, ks, parentKey);
+		result = parseSingleCondition (key, singleCondition, suffixList, ks, parentKey);
 		for (int i = startPos - 1; i < endPos + 1; ++i)
 			localCondition[i] = ' ';
 		localCondition[startPos - 1] = '\'';
@@ -557,11 +607,12 @@ static CondResult parseCondition (const char * condition, const Key * suffixList
 static CondResult parseConditionString (const Key * meta, const Key * suffixList, Key * parentKey, Key * key, KeySet * ks, Operation op)
 {
 	const char * conditionString = keyString (meta);
-	const char * regexString = "((\\(((.*)?)\\))[[:space:]]*\\?[[:space:]]*(\\(((.*)?)\\)))($|([[:space:]]*:[[:space:]]*(\\((.*)\\))))";
-
-	regex_t regex;
+	const char * regexString1 = "(\\(((.*)?)\\))[[:space:]]*\\?";
+	const char * regexString2 = "\\?[[:space:]]*(\\(((.*)?)\\))";
+	const char * regexString3 = ":[[:space:]]*(\\(((.*)?)\\))";
+	regex_t regex1, regex2, regex3;
 	CondResult ret;
-	if ((ret = regcomp (&regex, regexString, REGEX_FLAGS_CONDITION)))
+	if ((ret = regcomp (&regex1, regexString1, REGEX_FLAGS_CONDITION)))
 	{
 		ELEKTRA_SET_ERROR (87, parentKey, "Couldn't compile regex: most likely out of memory"); // the regex compiles so the only
 		// possible error would be out of
@@ -569,23 +620,45 @@ static CondResult parseConditionString (const Key * meta, const Key * suffixList
 		ksDel (ks);
 		return ERROR;
 	}
-	int subMatches = 12;
-	regmatch_t m[subMatches];
-	char * ptr = (char *)conditionString;
-	int nomatch = regexec (&regex, ptr, subMatches, m, 0);
-	if (nomatch)
+	if ((ret = regcomp (&regex2, regexString2, REGEX_FLAGS_CONDITION)))
 	{
-		ELEKTRA_SET_ERRORF (134, parentKey, "Invalid syntax: \"%s\". Check kdb info conditionals for additional information\n",
-				    conditionString);
-		regfree (&regex);
+		ELEKTRA_SET_ERROR (87, parentKey, "Couldn't compile regex: most likely out of memory"); // the regex compiles so the only
+		// possible error would be out of
+		// memory
+		regfree (&regex1);
 		ksDel (ks);
 		return ERROR;
 	}
-	if (m[2].rm_so == -1 || m[6].rm_so == -1)
+	if ((ret = regcomp (&regex3, regexString3, REGEX_FLAGS_CONDITION)))
 	{
-		ELEKTRA_SET_ERRORF (134, parentKey, "Invalid syntax: \"%s\". Check kdb info conditionals for additional information\n",
+		ELEKTRA_SET_ERROR (87, parentKey, "Couldn't compile regex: most likely out of memory"); // the regex compiles so the only
+		// possible error would be out of
+		// memory
+		regfree (&regex1);
+		regfree (&regex2);
+		ksDel (ks);
+		return ERROR;
+	}
+	int subMatches = 6;
+	regmatch_t m[subMatches];
+	int nomatch = regexec (&regex1, conditionString, subMatches, m, 0);
+	if (nomatch)
+	{
+		ELEKTRA_SET_ERRORF (134, parentKey, "Invalid syntax: \"%s\". Check kdb info conditionals for additional information",
 				    conditionString);
-		regfree (&regex);
+		regfree (&regex1);
+		regfree (&regex2);
+		regfree (&regex3);
+		ksDel (ks);
+		return ERROR;
+	}
+	if (m[1].rm_so == -1)
+	{
+		ELEKTRA_SET_ERRORF (134, parentKey, "Invalid syntax: \"%s\". Check kdb info conditionals for additional information",
+				    conditionString);
+		regfree (&regex1);
+		regfree (&regex2);
+		regfree (&regex3);
 		ksDel (ks);
 		return ERROR;
 	}
@@ -594,34 +667,67 @@ static CondResult parseConditionString (const Key * meta, const Key * suffixList
 	char * elseexpr = NULL;
 	int startPos;
 	int endPos;
-	startPos = m[2].rm_so + (ptr - conditionString);
-	endPos = m[2].rm_eo + (ptr - conditionString);
+	startPos = m[1].rm_so;
+	endPos = m[1].rm_eo;
 	condition = elektraMalloc (endPos - startPos + 1);
 	strncpy (condition, conditionString + startPos, endPos - startPos);
 	condition[endPos - startPos] = '\0';
+	nomatch = regexec (&regex2, conditionString, subMatches, m, 0);
+	if (nomatch)
+	{
+		ELEKTRA_SET_ERRORF (134, parentKey, "Invalid syntax: \"%s\". Check kdb info conditionals for additional information",
+				    conditionString);
+		regfree (&regex1);
+		regfree (&regex2);
+		regfree (&regex3);
+		ksDel (ks);
+		return ERROR;
+	}
+	if (m[1].rm_so == -1)
+	{
+		ELEKTRA_SET_ERRORF (134, parentKey, "Invalid syntax: \"%s\". Check kdb info conditionals for additional information",
+				    conditionString);
+		regfree (&regex1);
+		regfree (&regex2);
+		regfree (&regex3);
+		ksDel (ks);
+		return ERROR;
+	}
 
-	startPos = m[5].rm_so + (ptr - conditionString);
-	endPos = m[5].rm_eo + (ptr - conditionString);
+	startPos = m[1].rm_so;
+	endPos = m[1].rm_eo;
 	thenexpr = elektraMalloc (endPos - startPos + 1);
 	strncpy (thenexpr, conditionString + startPos, endPos - startPos);
 	thenexpr[endPos - startPos] = '\0';
 
-	if (m[10].rm_so != -1)
+	nomatch = regexec (&regex3, conditionString, subMatches, m, 0);
+	if (!nomatch)
 	{
-		startPos = m[10].rm_so + (ptr - conditionString);
-		endPos = m[10].rm_eo + (ptr - conditionString);
+		if (m[1].rm_so == -1)
+		{
+			ELEKTRA_SET_ERRORF (134, parentKey,
+					    "Invalid syntax: \"%s\". Check kdb info conditionals for additional information",
+					    conditionString);
+			regfree (&regex1);
+			regfree (&regex2);
+			regfree (&regex3);
+			ksDel (ks);
+			return ERROR;
+		}
+		thenexpr[strlen (thenexpr) - ((m[0].rm_eo - m[0].rm_so))] = '\0';
+		startPos = m[1].rm_so;
+		endPos = m[1].rm_eo;
 		elseexpr = elektraMalloc (endPos - startPos + 1);
 		strncpy (elseexpr, conditionString + startPos, endPos - startPos);
 		elseexpr[endPos - startPos] = '\0';
 	}
 
-
-	ret = parseCondition (condition, suffixList, ks, parentKey);
+	ret = parseCondition (key, condition, suffixList, ks, parentKey);
 	if (ret == TRUE)
 	{
 		if (op == ASSIGN)
 		{
-			const char * assign = isAssign (thenexpr, parentKey, ks);
+			const char * assign = isAssign (key, thenexpr, parentKey, ks);
 			if (assign != NULL)
 			{
 				keySetString (key, assign);
@@ -631,23 +737,21 @@ static CondResult parseConditionString (const Key * meta, const Key * suffixList
 			else
 			{
 				ret = ERROR;
-				ELEKTRA_SET_ERRORF (134, parentKey,
-						    "Invalid syntax: \"%s\". Check kdb info conditionals for additional information\n",
-						    thenexpr);
 				goto CleanUp;
 			}
 		}
 		else
 		{
-			ret = parseCondition (thenexpr, suffixList, ks, parentKey);
+			ret = parseCondition (key, thenexpr, suffixList, ks, parentKey);
 			if (ret == FALSE)
 			{
-				ELEKTRA_SET_ERRORF (135, parentKey, "Validation of %s failed. (%s failed)", conditionString, thenexpr);
+				ELEKTRA_SET_ERRORF (135, parentKey, "Validation of Key %s: %s failed. (%s failed)",
+						    keyName (key) + strlen (keyName (parentKey)) + 1, conditionString, thenexpr);
 			}
 			else if (ret == ERROR)
 			{
 				ELEKTRA_SET_ERRORF (134, parentKey,
-						    "Invalid syntax: \"%s\". Check kdb info conditionals for additional information\n",
+						    "Invalid syntax: \"%s\". Check kdb info conditionals for additional information",
 						    thenexpr);
 			}
 		}
@@ -658,7 +762,7 @@ static CondResult parseConditionString (const Key * meta, const Key * suffixList
 		{
 			if (op == ASSIGN)
 			{
-				const char * assign = isAssign (elseexpr, parentKey, ks);
+				const char * assign = isAssign (key, elseexpr, parentKey, ks);
 				if (assign != NULL)
 				{
 					keySetString (key, assign);
@@ -668,27 +772,23 @@ static CondResult parseConditionString (const Key * meta, const Key * suffixList
 				else
 				{
 					ret = ERROR;
-					ELEKTRA_SET_ERRORF (
-						134, parentKey,
-						"Invalid syntax: \"%s\". Check kdb info conditionals for additional information\n",
-						elseexpr);
 					goto CleanUp;
 				}
 			}
 			else
 			{
-				ret = parseCondition (elseexpr, suffixList, ks, parentKey);
+				ret = parseCondition (key, elseexpr, suffixList, ks, parentKey);
+
 				if (ret == FALSE)
 				{
-					ELEKTRA_SET_ERRORF (135, parentKey, "Validation of %s failed. (%s failed)", conditionString,
-							    elseexpr);
+					ELEKTRA_SET_ERRORF (135, parentKey, "Validation of Key %s: %s failed. (%s failed)",
+							    keyName (key) + strlen (keyName (parentKey)) + 1, conditionString, elseexpr);
 				}
 				else if (ret == ERROR)
 				{
 					ELEKTRA_SET_ERRORF (
 						134, parentKey,
-						"Invalid syntax: \"%s\". Check kdb info conditionals for additional information\n",
-						elseexpr);
+						"Invalid syntax: \"%s\". Check kdb info conditionals for additional information", elseexpr);
 				}
 			}
 		}
@@ -699,7 +799,7 @@ static CondResult parseConditionString (const Key * meta, const Key * suffixList
 	}
 	else if (ret == ERROR)
 	{
-		ELEKTRA_SET_ERRORF (134, parentKey, "Invalid syntax: \"%s\". Check kdb info conditionals for additional information\n",
+		ELEKTRA_SET_ERRORF (134, parentKey, "Invalid syntax: \"%s\". Check kdb info conditionals for additional information",
 				    condition);
 	}
 
@@ -707,7 +807,9 @@ CleanUp:
 	elektraFree (condition);
 	elektraFree (thenexpr);
 	if (elseexpr) elektraFree (elseexpr);
-	regfree (&regex);
+	regfree (&regex1);
+	regfree (&regex2);
+	regfree (&regex3);
 	ksDel (ks);
 	return ret;
 }
@@ -821,8 +923,8 @@ int elektraConditionalsSet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned EL
 Plugin * ELEKTRA_PLUGIN_EXPORT (conditionals)
 {
 	// clang-format off
-	return elektraPluginExport ("conditionals",
-					ELEKTRA_PLUGIN_GET, &elektraConditionalsGet,
-					ELEKTRA_PLUGIN_SET, &elektraConditionalsSet,
-					ELEKTRA_PLUGIN_END);
+    return elektraPluginExport ("conditionals",
+	    ELEKTRA_PLUGIN_GET, &elektraConditionalsGet,
+	    ELEKTRA_PLUGIN_SET, &elektraConditionalsSet,
+	    ELEKTRA_PLUGIN_END);
 }
