@@ -18,7 +18,7 @@ static void test_ifthenelseint ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "153", KEY_META, "check/condition",
-					"(totest== '153') ? (bla/val1 == '100') : (bla/val2 == '100')", KEY_END),
+					"(../totest== '153') ? (../bla/val1 == '100') : (../bla/val2 == '100')", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
@@ -34,7 +34,7 @@ static void test_ifthenint ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "153", KEY_META, "check/condition",
-					"(     totest   !=     '15'  ) ? (bla/val1 == '100')", KEY_END),
+					"(     ../totest   !=     '15'  ) ? (../bla/val1 == '100')", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
@@ -50,7 +50,7 @@ static void test_ifthenltint ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "153", KEY_META, "check/condition",
-					"(     totest   <    '153'    ) ? (bla/val1 == '100')", KEY_END),
+					"(     ./   <    '153'    ) ? (../bla/val1 == '100')", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
@@ -66,7 +66,7 @@ static void test_ifthengtint ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "153", KEY_META, "check/condition",
-					"(totest>'153') ? (bla/val1 == '100') : (bla/val2 <= '1')", KEY_END),
+					"(./>'153') ? (../bla/val1 == '100') : (../bla/val2 <= '1')", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
@@ -83,7 +83,7 @@ static void test_ifthenkey ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "153", KEY_META, "check/condition",
-					"(totest>bla/val3) ? (bla/val1 == '100') :  (bla/val2 <= '1')", KEY_END),
+					"(../totest>@/bla/val3) ? (../bla/val1 == '100') :  (../bla/val2 <= '1')", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
@@ -101,7 +101,7 @@ static void test_emptyisempty ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "", KEY_META, "check/condition",
-					"(totest=='') ? (bla/val1 == '100') : (bla/val2 <= '1')", KEY_END),
+					"(../totest=='') ? (../bla/val1 == '100') : (../bla/val2 <= '1')", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
@@ -119,7 +119,7 @@ static void test_notempty ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "153", KEY_META, "check/condition",
-					"(totest!='') ? (bla/val1 == '100') : (bla/val2 <= '1')", KEY_END),
+					"(../totest!='') ? (../bla/val1 == '100') : (../bla/val2 <= '1')", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
@@ -136,7 +136,7 @@ static void test_ifsetthenval ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "", KEY_META, "check/condition",
-					"(totest=='') ? (totest := 'BLA')", KEY_END),
+					"(../totest=='') ? (../totest := 'BLA')", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
@@ -154,7 +154,7 @@ static void test_ifsetthenkey ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "", KEY_META, "check/condition",
-					"(totest=='') ? (totest := bla/val1)", KEY_END),
+					"(./=='') ? (./ := ../bla/val1)", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
@@ -172,7 +172,7 @@ static void test_assignThen ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "Hello", KEY_META, "assign/condition",
-					"(totest=='Hello') ? ('World')", KEY_END),
+					"(../totest=='Hello') ? ('World')", KEY_END),
 			     KS_END);
 	KeySet * conf = ksNew (0, KS_END);
 	PLUGIN_OPEN ("conditionals");
@@ -189,7 +189,7 @@ static void test_assignElse ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "Hello", KEY_META, "assign/condition",
-					"(totest=='Hell') ? ('World') : ('Fail')", KEY_END),
+					"(../totest=='Hell') ? ('World') : ('Fail')", KEY_END),
 			     KS_END);
 	KeySet * conf = ksNew (0, KS_END);
 	PLUGIN_OPEN ("conditionals");
@@ -206,7 +206,7 @@ static void test_assignKeyThen ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "Hello", KEY_META, "assign/condition",
-					"(totest=='Hello') ? (then/key)", KEY_END),
+					"(../totest=='Hello') ? (../then/key)", KEY_END),
 			     keyNew ("user/tests/conditionals/then/key", KEY_VALUE, "World", KEY_END),
 			     keyNew ("user/tests/conditionals/elseVal", KEY_VALUE, "Fail", KEY_END), KS_END);
 	KeySet * conf = ksNew (0, KS_END);
@@ -224,7 +224,7 @@ static void test_assignKeyElse ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "Hello", KEY_META, "assign/condition",
-					"(totest=='Hell') ? (then/key) : (elseVal)", KEY_END),
+					"(../totest=='Hell') ? (../then/key) : (../elseVal)", KEY_END),
 			     keyNew ("user/tests/conditionals/then/key", KEY_VALUE, "World", KEY_END),
 			     keyNew ("user/tests/conditionals/elseVal", KEY_VALUE, "Fail", KEY_END), KS_END);
 	KeySet * conf = ksNew (0, KS_END);
@@ -242,7 +242,7 @@ static void test_doesntExistSuccess ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "5", KEY_META, "check/condition",
-					"(totest<bla/val1) ? (! bla/val4)", KEY_END),
+					"(../totest<../bla/val1) ? (! ../bla/val4)", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END),
@@ -261,7 +261,7 @@ static void test_doesntExistFail ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "5", KEY_META, "check/condition",
-					"(totest<bla/val1) ? (! bla/val1)", KEY_END),
+					"(../totest<../bla/val1) ? (! ../bla/val1)", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END),
@@ -279,12 +279,13 @@ static void test_doesntExistFail ()
 static void test_nested1Success ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
-	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "5", KEY_META, "check/condition",
-					"(totest<bla/val1) ? ((bla/result == 'result1') || (bla/result == 'result3'))", KEY_END),
-			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
-			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
-			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END),
-			     keyNew ("user/tests/conditionals/bla/result", KEY_VALUE, "result3", KEY_END), KS_END);
+	KeySet * ks =
+		ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "5", KEY_META, "check/condition",
+				  "(../totest<../bla/val1) ? ((../bla/result == 'result1') || (../bla/result == 'result3'))", KEY_END),
+		       keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
+		       keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
+		       keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END),
+		       keyNew ("user/tests/conditionals/bla/result", KEY_VALUE, "result3", KEY_END), KS_END);
 
 	KeySet * conf = ksNew (0, KS_END);
 	PLUGIN_OPEN ("conditionals");
@@ -298,12 +299,13 @@ static void test_nested1Success ()
 static void test_nested1Fail ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
-	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "5", KEY_META, "check/condition",
-					"(totest<bla/val1) ? ((bla/result == 'result1') || (bla/result == 'result2'))", KEY_END),
-			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
-			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
-			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END),
-			     keyNew ("user/tests/conditionals/bla/result", KEY_VALUE, "result3", KEY_END), KS_END);
+	KeySet * ks =
+		ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "5", KEY_META, "check/condition",
+				  "(../totest<../bla/val1) ? ((../bla/result == 'result1') || (../bla/result == 'result2'))", KEY_END),
+		       keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
+		       keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
+		       keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END),
+		       keyNew ("user/tests/conditionals/bla/result", KEY_VALUE, "result3", KEY_END), KS_END);
 	KeySet * conf = ksNew (0, KS_END);
 	PLUGIN_OPEN ("conditionals");
 	ksRewind (ks);
@@ -317,14 +319,14 @@ static void test_nested1Fail ()
 static void test_nested2Success ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
-	KeySet * ks =
-		ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "5", KEY_META, "check/condition",
-				  "(totest<bla/val1) ? ((bla/val1 == '100') && ((bla/result == 'result1') || (bla/result == 'result3')))",
-				  KEY_END),
-		       keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
-		       keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
-		       keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END),
-		       keyNew ("user/tests/conditionals/bla/result", KEY_VALUE, "result3", KEY_END), KS_END);
+	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "5", KEY_META, "check/condition",
+					"(../totest<../bla/val1) ? ((../bla/val1 == '100') && ((../bla/result == 'result1') || "
+					"(../bla/result == 'result3')))",
+					KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/result", KEY_VALUE, "result3", KEY_END), KS_END);
 
 	KeySet * conf = ksNew (0, KS_END);
 	PLUGIN_OPEN ("conditionals");
@@ -338,14 +340,14 @@ static void test_nested2Success ()
 static void test_nested2Fail ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
-	KeySet * ks =
-		ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "5", KEY_META, "check/condition",
-				  "(totest<bla/val1) ? ((bla/val1 == '100') && ((bla/result == 'result1') || (bla/result == 'result2')))",
-				  KEY_END),
-		       keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
-		       keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
-		       keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END),
-		       keyNew ("user/tests/conditionals/bla/result", KEY_VALUE, "result3", KEY_END), KS_END);
+	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "5", KEY_META, "check/condition",
+					"(../totest<../bla/val1) ? ((../bla/val1 == '100') && ((../bla/result == 'result1') || "
+					"(../bla/result == 'result2')))",
+					KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/result", KEY_VALUE, "result3", KEY_END), KS_END);
 	KeySet * conf = ksNew (0, KS_END);
 	PLUGIN_OPEN ("conditionals");
 	ksRewind (ks);
@@ -359,8 +361,8 @@ static void test_suffix ()
 {
 	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
 	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "2%", KEY_META, "check/condition",
-					"(totest >= '10%') ? (bla/val1 == '50%') : (bla/val3 == '3%')", KEY_META, "condition/validsuffix",
-					"'%', '$'", KEY_END),
+					"(../totest >= '10%') ? (../bla/val1 == '50%') : (../bla/val3 == '3%')", KEY_META,
+					"condition/validsuffix", "'%', '$'", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100%", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50%", KEY_END),
 			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3%", KEY_END), KS_END);
@@ -373,6 +375,77 @@ static void test_suffix ()
 	PLUGIN_CLOSE ();
 }
 
+static void test_elseWhitespace ()
+{
+	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
+	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "2", KEY_META, "check/condition",
+					"(../totest >= '10') ? (../bla/val1 == '50'): (../bla/val3 == '3')", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
+	KeySet * conf = ksNew (0, KS_END);
+	PLUGIN_OPEN ("conditionals");
+	ksRewind (ks);
+	succeed_if (plugin->kdbGet (plugin, ks, parentKey) == 1, "error");
+	ksDel (ks);
+	keyDel (parentKey);
+	PLUGIN_CLOSE ();
+}
+
+static void test_elseWhitespace2 ()
+{
+	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
+	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "2", KEY_META, "check/condition",
+					"(../totest >= '10') ? (../bla/val1 == '50') :(../bla/val3 == '3')", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
+	KeySet * conf = ksNew (0, KS_END);
+	PLUGIN_OPEN ("conditionals");
+	ksRewind (ks);
+	succeed_if (plugin->kdbGet (plugin, ks, parentKey) == 1, "error");
+	ksDel (ks);
+	keyDel (parentKey);
+	PLUGIN_CLOSE ();
+}
+
+static void test_elseWhitespace3 ()
+{
+	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
+	KeySet * ks = ksNew (5, keyNew ("user/tests/conditionals/totest", KEY_VALUE, "2", KEY_META, "check/condition",
+					"(../totest >= '10') ? (../bla/val1 == '50'):(../bla/val3 == '3')", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
+			     keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END), KS_END);
+	KeySet * conf = ksNew (0, KS_END);
+	PLUGIN_OPEN ("conditionals");
+	ksRewind (ks);
+	succeed_if (plugin->kdbGet (plugin, ks, parentKey) == 1, "error");
+	ksDel (ks);
+	keyDel (parentKey);
+	PLUGIN_CLOSE ();
+}
+
+static void test_doubleUp ()
+{
+	Key * parentKey = keyNew ("user/tests/conditionals", KEY_VALUE, "", KEY_END);
+	KeySet * ks =
+		ksNew (5, keyNew ("user/tests/conditionals/bla/totest", KEY_VALUE, "5", KEY_META, "check/condition",
+				  "(../../bla/totest<../../bla/val1) ? ((../../bla/val1 == '100') && ((../../bla/result == 'result1') || "
+				  "(../../bla/result == 'result2')))",
+				  KEY_END),
+		       keyNew ("user/tests/conditionals/bla/val1", KEY_VALUE, "100", KEY_END),
+		       keyNew ("user/tests/conditionals/bla/val2", KEY_VALUE, "50", KEY_END),
+		       keyNew ("user/tests/conditionals/bla/val3", KEY_VALUE, "3", KEY_END),
+		       keyNew ("user/tests/conditionals/bla/result", KEY_VALUE, "result3", KEY_END), KS_END);
+	KeySet * conf = ksNew (0, KS_END);
+	PLUGIN_OPEN ("conditionals");
+	ksRewind (ks);
+	succeed_if (plugin->kdbGet (plugin, ks, parentKey) == -1, "error");
+	ksDel (ks);
+	keyDel (parentKey);
+	PLUGIN_CLOSE ();
+}
 int main (int argc, char ** argv)
 {
 	printf ("CONDITIONALS     TESTS\n");
@@ -397,10 +470,13 @@ int main (int argc, char ** argv)
 	test_nested1Fail ();
 	test_nested2Success ();
 	test_nested2Fail ();
-
 	test_doesntExistSuccess ();
 	test_doesntExistFail ();
 	test_suffix ();
+	test_elseWhitespace ();
+	test_elseWhitespace2 ();
+	test_elseWhitespace3 ();
+	test_doubleUp ();
 	printf ("\ntestmod_conditionals RESULTS: %d test(s) done. %d error(s).\n", nbTest, nbError);
 
 	return nbError;
