@@ -11,13 +11,15 @@
 #define ELEKTRA_PLUGIN_LIBCRYPTO_OPERATIONS_H
 
 #include <kdb.h>
+#include <kdbtypes.h>
 
 #define ELEKTRA_CRYPTO_SSL_KEYSIZE (32)
 #define ELEKTRA_CRYPTO_SSL_BLOCKSIZE (16)
 
+char * elektraCryptoOpenSSLCreateRandomString (Key * errorKey, const kdb_unsigned_short_t length);
 int elektraCryptoOpenSSLInit (Key * errorKey);
-void elektraCryptoOpenSSLTeardown (void);
-int elektraCryptoOpenSSLHandleCreate (elektraCryptoHandle ** handle, KeySet * config, Key * errorKey);
+int elektraCryptoOpenSSLHandleCreate (elektraCryptoHandle ** handle, KeySet * config, Key * errorKey, Key * k,
+				      const enum ElektraCryptoOperation op);
 void elektraCryptoOpenSSLHandleDestroy (elektraCryptoHandle * handle);
 int elektraCryptoOpenSSLEncrypt (elektraCryptoHandle * handle, Key * k, Key * errorKey);
 int elektraCryptoOpenSSLDecrypt (elektraCryptoHandle * handle, Key * k, Key * errorKey);
