@@ -10,35 +10,35 @@
 #include "keytometa.h"
 
 #ifndef HAVE_KDBCONFIG
-# include "kdbconfig.h"
+#include "kdbconfig.h"
 #endif
 
 
 #include <errno.h>
-#include <stdlib.h>
 #include <stdbool.h>
+#include <stdlib.h>
 
-static const char* CONVERT_METANAME = "convert/metaname";
-static const char* CONVERT_TARGET = "convert/to";
-static const char* CONVERT_APPEND_SAMELEVEL = "convert/append/samelevel";
-static const char* CONVERT_APPENDMODE = "convert/append";
+static const char * CONVERT_METANAME = "convert/metaname";
+static const char * CONVERT_TARGET = "convert/to";
+static const char * CONVERT_APPEND_SAMELEVEL = "convert/append/samelevel";
+static const char * CONVERT_APPENDMODE = "convert/append";
 
 /*
  * Wrapper for the function comparing by order meta data. As
  * qsort is not stable returning 0 on missing order may
  * mess up the original order.
  */
-int elektraKeyCmpOrderWrapper(const void *a, const void *b)
+int elektraKeyCmpOrderWrapper (const void * a, const void * b)
 {
-	const Key **ka = (const Key **) a;
-	const Key **kb = (const Key **) b;
+	const Key ** ka = (const Key **)a;
+	const Key ** kb = (const Key **)b;
 
-	int orderResult = elektraKeyCmpOrder(*ka, *kb);
+	int orderResult = elektraKeyCmpOrder (*ka, *kb);
 
 	/* comparing the order meta could not order the keys
 	 * revert to comparing the names instead
 	 */
-	if (orderResult == 0) return keyCmp(*ka, *kb);
+	if (orderResult == 0) return keyCmp (*ka, *kb);
 
 	return orderResult;
 }
@@ -46,11 +46,11 @@ int elektraKeyCmpOrderWrapper(const void *a, const void *b)
 /* The KeySet MUST be sorted alphabetically (or at least ascending
  * by the length of keynames) for this function to work
  */
-static Key *findNearestParent(Key *key, KeySet *ks)
+static Key * findNearestParent (Key * key, KeySet * ks)
 {
-	Key *current;
-	ksSetCursor(ks, ksGetSize(ks) - 1);
-	while ((current = ksPrev(ks)) != 0)
+	Key * current;
+	ksSetCursor (ks, ksGetSize (ks) - 1);
+	while ((current = ksPrev (ks)) != 0)
 	{
 		if (keyIsBelow (current, key))
 		{
@@ -78,79 +78,79 @@ static Key *findNearestParent(Key *key, KeySet *ks)
  * @see keyGetValueSize(Key *key)
  *
  */
-int elektraKeyAppendMetaLine (Key *target, const char *metaName, const char *line)
+int elektraKeyAppendMetaLine (Key * target, const char * metaName, const char * line)
 {
 	if (!target) return 0;
 	if (!metaName) return 0;
 	if (!line) return 0;
 
-	if (!keyGetMeta(target, metaName))
+	if (!keyGetMeta (target, metaName))
 	{
-		keySetMeta(target, metaName, line);
-		return keyGetValueSize(keyGetMeta(target, metaName));
+		keySetMeta (target, metaName, line);
+		return keyGetValueSize (keyGetMeta (target, metaName));
 	}
 
-	const Key *existingMeta = keyGetMeta(target, metaName);
-	char *buffer = elektraMalloc (keyGetValueSize(existingMeta) + strlen (line) + 1);
+	const Key * existingMeta = keyGetMeta (target, metaName);
+	char * buffer = elektraMalloc (keyGetValueSize (existingMeta) + strlen (line) + 1);
 	if (!buffer) return 0;
 
-	keyGetString(existingMeta, buffer, keyGetValueSize(existingMeta));
+	keyGetString (existingMeta, buffer, keyGetValueSize (existingMeta));
 	strcat (buffer, "\n");
 	strncat (buffer, line, strlen (line));
 
-	keySetMeta(target, metaName, buffer);
+	keySetMeta (target, metaName, buffer);
 	elektraFree (buffer);
-	return keyGetValueSize(keyGetMeta(target, metaName));
+	return keyGetValueSize (keyGetMeta (target, metaName));
 }
 
-static const char *getAppendMode (Key *key) {
-	const Key *appendModeKey = keyGetMeta (key, CONVERT_APPENDMODE);
-	const char *appendMode;
+static const char * getAppendMode (Key * key)
+{
+	const Key * appendModeKey = keyGetMeta (key, CONVERT_APPENDMODE);
+	const char * appendMode;
 
 	/* append to the next key is the default */
-	appendMode = appendModeKey != 0 ? keyString(appendModeKey) : "next";
+	appendMode = appendModeKey != 0 ? keyString (appendModeKey) : "next";
 	return appendMode;
 }
 
-void removeKeyFromResult(Key* convertKey, Key* target, KeySet* orig)
+void removeKeyFromResult (Key * convertKey, Key * target, KeySet * orig)
 {
 	/* remember which key this key was converted to
 	 * before removing it from the result
 	 */
 	keySetMeta (convertKey, CONVERT_TARGET, keyName (target));
-	Key *key = ksLookup (orig, convertKey, KDB_O_POP);
+	Key * key = ksLookup (orig, convertKey, KDB_O_POP);
 	keyDel (key);
 }
 
-static void flushConvertedKeys(Key *target, KeySet *converted, KeySet *orig)
+static void flushConvertedKeys (Key * target, KeySet * converted, KeySet * orig)
 {
-	if (ksGetSize(converted) == 0) return;
+	if (ksGetSize (converted) == 0) return;
 
 	ksRewind (converted);
-	Key *current;
-	Key *appendTarget;
+	Key * current;
+	Key * appendTarget;
 
-	while ((current = ksNext(converted)))
+	while ((current = ksNext (converted)))
 	{
 		appendTarget = target;
-		const char *metaName = keyString (keyGetMeta(current, CONVERT_METANAME));
+		const char * metaName = keyString (keyGetMeta (current, CONVERT_METANAME));
 
-		Key *currentDup = keyDup(current);
-		Key *targetDup = keyDup(appendTarget);
-		keySetBaseName(currentDup, 0);
-		keySetBaseName(targetDup, 0);
+		Key * currentDup = keyDup (current);
+		Key * targetDup = keyDup (appendTarget);
+		keySetBaseName (currentDup, 0);
+		keySetBaseName (targetDup, 0);
 
 		/* the convert key request to be converted to a key
 		 * on the same level, but the target is below or above
 		 */
-		if (keyGetMeta (current, CONVERT_APPEND_SAMELEVEL) &&
-				keyCmp(currentDup, targetDup))
+		if (keyGetMeta (current, CONVERT_APPEND_SAMELEVEL) && keyCmp (currentDup, targetDup))
 		{
 			appendTarget = 0;
 		}
 
-		keyDel(currentDup);
-		keyDel(targetDup);
+		keyDel (currentDup);
+		keyDel (targetDup);
 
 		/* no target key was found of the target
 		 * was discarded for some reason. Revert to the parent
@@ -160,20 +160,20 @@ static void flushConvertedKeys(Key *target, KeySet *converted, KeySet *orig)
 			appendTarget = findNearestParent (current, orig);
 		}
 
-		elektraKeyAppendMetaLine(appendTarget, metaName, keyString(current));
+		elektraKeyAppendMetaLine (appendTarget, metaName, keyString (current));
 		removeKeyFromResult (current, target, orig);
 	}
 
-	ksClear(converted);
+	ksClear (converted);
 }
 
-static KeySet *convertKeys(Key **keyArray, size_t numKeys, KeySet *orig)
+static KeySet * convertKeys (Key ** keyArray, size_t numKeys, KeySet * orig)
 {
-	Key *current = 0;
-	Key *prevAppendTarget = 0;
-	KeySet *prevConverted = ksNew(0, KS_END);
-	KeySet *nextConverted = ksNew(0, KS_END);
-	KeySet *result = ksNew(0, KS_END);
+	Key * current = 0;
+	Key * prevAppendTarget = 0;
+	KeySet * prevConverted = ksNew (0, KS_END);
+	KeySet * nextConverted = ksNew (0, KS_END);
+	KeySet * result = ksNew (0, KS_END);
 
 	for (size_t index = 0; index < numKeys; index++)
 	{
@@ -193,10 +193,10 @@ static KeySet *convertKeys(Key **keyArray, size_t numKeys, KeySet *orig)
 			continue;
 		}
 
-		const char *appendMode = getAppendMode (current);
-		const char *metaName = keyString (keyGetMeta (current, CONVERT_METANAME));
+		const char * appendMode = getAppendMode (current);
+		const char * metaName = keyString (keyGetMeta (current, CONVERT_METANAME));
 
-		Key *bufferKey = 0;
+		Key * bufferKey = 0;
 		if (!strcmp (appendMode, "previous"))
 		{
 			ksAppendKey (prevConverted, current);
@@ -209,10 +209,10 @@ static KeySet *convertKeys(Key **keyArray, size_t numKeys, KeySet *orig)
 
 		if (!strcmp (appendMode, "parent"))
 		{
-			Key *parent = findNearestParent (current, orig);
+			Key * parent = findNearestParent (current, orig);
 			elektraKeyAppendMetaLine (parent, metaName, keyString (current));
 			ksAppendKey (result, current);
-			removeKeyFromResult(current, parent, orig);
+			removeKeyFromResult (current, parent, orig);
 		}
 
 		if (bufferKey)
@@ -233,95 +233,99 @@ static KeySet *convertKeys(Key **keyArray, size_t numKeys, KeySet *orig)
 	return result;
 }
 
-int elektraKeyToMetaGet(Plugin *handle, KeySet *returned, Key *parentKey ELEKTRA_UNUSED)
+int elektraKeyToMetaGet (Plugin * handle, KeySet * returned, Key * parentKey ELEKTRA_UNUSED)
 {
 	int errnosave = errno;
 
 	/* configuration only */
-	if (!strcmp (keyName(parentKey), "system/elektra/modules/keytometa"))
+	if (!strcmp (keyName (parentKey), "system/elektra/modules/keytometa"))
 	{
-		KeySet *info =
-			#include "contract.h"
+		KeySet * info =
+#include "contract.h"
 
-		ksAppend (returned, info);
+			ksAppend (returned, info);
 		ksDel (info);
 		return 1;
 	}
 
-	Key **keyArray = calloc (ksGetSize(returned), sizeof (Key *));
-	int ret = elektraKsToMemArray(returned, keyArray);
+	Key ** keyArray = calloc (ksGetSize (returned), sizeof (Key *));
+	int ret = elektraKsToMemArray (returned, keyArray);
 
-	if (ret < 0) {
+	if (ret < 0)
+	{
 		elektraFree (keyArray);
-		ELEKTRA_SET_ERROR(87, parentKey, strerror(errno));
+		ELEKTRA_SET_ERROR (87, parentKey, strerror (errno));
 		errno = errnosave;
 		return 0;
 	}
 
-	size_t numKeys = ksGetSize(returned);
+	size_t numKeys = ksGetSize (returned);
 	qsort (keyArray, numKeys, sizeof (Key *), elektraKeyCmpOrderWrapper);
 
-	KeySet *convertedKeys = convertKeys(keyArray, numKeys, returned);
+	KeySet * convertedKeys = convertKeys (keyArray, numKeys, returned);
 
 	elektraFree (keyArray);
 
 	/* cleanup what might have been left from a previous call */
-	KeySet *old = elektraPluginGetData(handle);
+	KeySet * old = elektraPluginGetData (handle);
 	if (old)
 	{
 		ksDel (old);
 	}
 
-	elektraPluginSetData(handle, convertedKeys);
+	elektraPluginSetData (handle, convertedKeys);
 
 	errno = errnosave;
 	return 1; /* success */
 }
 
 
-
-int elektraKeyToMetaSet(Plugin *handle, KeySet *returned, Key *parentKey ELEKTRA_UNUSED)
+int elektraKeyToMetaSet (Plugin * handle, KeySet * returned, Key * parentKey ELEKTRA_UNUSED)
 {
-	KeySet *converted = elektraPluginGetData(handle);
+	KeySet * converted = elektraPluginGetData (handle);
 
 	/* nothing to do */
 	if (converted == 0) return 1;
 
 	ksRewind (converted);
 
-	char *saveptr = 0;
-	char *value = 0;
-	Key *current;
-	Key *previous = 0;
+	char * saveptr = 0;
+	char * value = 0;
+	Key * current;
+	Key * previous = 0;
 	while ((current = ksNext (converted)) != 0)
 	{
-		const Key *targetName = keyGetMeta (current, CONVERT_TARGET);
-		const Key *metaName = keyGetMeta (current, CONVERT_METANAME);
+		const Key * targetName = keyGetMeta (current, CONVERT_TARGET);
+		const Key * metaName = keyGetMeta (current, CONVERT_METANAME);
 
 		/* they should always exist, just to be sure */
-		if (targetName && metaName) {
-			Key *target = ksLookupByName(returned, keyString(targetName), KDB_O_NONE);
+		if (targetName && metaName)
+		{
+			Key * target = ksLookupByName (returned, keyString (targetName), KDB_O_NONE);
 
 			/* this might be NULL as the key might have been deleted */
-			if (target) {
+			if (target)
+			{
 
-				char *result = 0;
+				char * result = 0;
 				if (target != previous)
 				{
 					/* handle the first meta line this means initializing strtok and related buffers */
 					elektraFree (value);
-					const Key *valueKey = keyGetMeta(target, keyString(metaName));
-					size_t valueSize = keyGetValueSize(valueKey);
+					const Key * valueKey = keyGetMeta (target, keyString (metaName));
+					size_t valueSize = keyGetValueSize (valueKey);
 					value = elektraMalloc (valueSize);
-					keyGetString(valueKey, value, valueSize);
-					keySetMeta(target, keyString(metaName), 0);
+					keyGetString (valueKey, value, valueSize);
+					keySetMeta (target, keyString (metaName), 0);
 					result = strtok_r (value, "\n", &saveptr);
-				} else {
+				}
+				else
+				{
 					/* just continue splitting the meta data */
 					result = strtok_r (NULL, "\n", &saveptr);
 				}
 
-				keySetString(current, result);
+				keySetString (current, result);
 
 				previous = target;
 			}
@@ -330,20 +334,20 @@ int elektraKeyToMetaSet(Plugin *handle, KeySet *returned, Key *parentKey ELEKTRA
 		keySetMeta (current, CONVERT_TARGET, 0);
 		keySetMeta (current, CONVERT_METANAME, 0);
 
-		ksAppendKey(returned, current);
+		ksAppendKey (returned, current);
 	}
 
 	elektraFree (value);
 
 	ksDel (converted);
-	elektraPluginSetData(handle, 0);
+	elektraPluginSetData (handle, 0);
 
 	return 1; /* success */
 }
 
-int elektraKeyToMetaClose(Plugin *handle, Key *errorKey ELEKTRA_UNUSED)
+int elektraKeyToMetaClose (Plugin * handle, Key * errorKey ELEKTRA_UNUSED)
 {
-	KeySet *old = elektraPluginGetData(handle);
+	KeySet * old = elektraPluginGetData (handle);
 
 	if (old)
 	{
@@ -353,8 +357,9 @@ int elektraKeyToMetaClose(Plugin *handle, Key *errorKey ELEKTRA_UNUSED)
 	return 1;
 }
 
-Plugin *ELEKTRA_PLUGIN_EXPORT(keytometa)
+Plugin * ELEKTRA_PLUGIN_EXPORT (keytometa)
 {
+	// clang-format off
 	return elektraPluginExport("keytometa",
 		ELEKTRA_PLUGIN_GET,	&elektraKeyToMetaGet,
 		ELEKTRA_PLUGIN_SET,	&elektraKeyToMetaSet,
