@@ -12,6 +12,9 @@
 #include "kdbconfig.h"
 #endif
 
+#define STRINGIFY(x) STRINGIFY2 (x)
+#define STRINGIFY2(x) #x
+
 #include <tests_plugin.h>
 
 static void init_env ()
@@ -27,7 +30,7 @@ static char * python_file (const char * filename)
 	if (!srcdir_rewrite)
 	{
 		/* no rewrite. just append our plugin name */
-		strcpy (filebuf, PYTHON_PLUGIN_NAME);
+		strcpy (filebuf, STRINGIFY (PYTHON_PLUGIN_NAME));
 		strcat (strcat (filebuf, "/"), filename);
 		return srcdir_file (filebuf);
 	}
@@ -36,7 +39,7 @@ static char * python_file (const char * filename)
 	*srcdir_rewrite = '\0';
 
 	/* append plugin name and delete last character */
-	strcat (strcat (filebuf, "/"), PYTHON_PLUGIN_NAME);
+	strcat (strcat (filebuf, "/"), STRINGIFY (PYTHON_PLUGIN_NAME));
 	*(filebuf + strlen (filebuf) - 1) = '\0';
 
 	strcat (strcat (filebuf, "/"), filename);
@@ -50,7 +53,7 @@ static void test_variable_passing ()
 
 	KeySet * conf = ksNew (1, keyNew ("user/script", KEY_VALUE, python_file ("python_plugin.py"), KEY_END),
 			       keyNew ("user/shutdown", KEY_VALUE, "1", KEY_END), keyNew ("user/print", KEY_END), KS_END);
-	PLUGIN_OPEN (PYTHON_PLUGIN_NAME);
+	PLUGIN_OPEN (STRINGIFY (PYTHON_PLUGIN_NAME));
 
 	Key * parentKey = keyNew ("user/from_c", KEY_END);
 	KeySet * ks = ksNew (0, KS_END);
@@ -79,14 +82,14 @@ static void test_two_scripts ()
 				keyNew ("user/shutdown", KEY_VALUE, "1", KEY_END), keyNew ("user/print", KEY_END), KS_END);
 
 	Key * errorKey = keyNew ("", KEY_END);
-	Plugin * plugin = elektraPluginOpen (PYTHON_PLUGIN_NAME, modules, conf, errorKey);
+	Plugin * plugin = elektraPluginOpen (STRINGIFY (PYTHON_PLUGIN_NAME), modules, conf, errorKey);
 	succeed_if (output_warnings (errorKey), "warnings in kdbOpen");
 	succeed_if (output_error (errorKey), "errors in kdbOpen");
 	exit_if_fail (plugin != NULL, "unable to load python plugin");
 	keyDel (errorKey);
 
 	Key * errorKey2 = keyNew ("", KEY_END);
-	Plugin * plugin2 = elektraPluginOpen (PYTHON_PLUGIN_NAME, modules, conf2, errorKey2);
+	Plugin * plugin2 = elektraPluginOpen (STRINGIFY (PYTHON_PLUGIN_NAME), modules, conf2, errorKey2);
 	succeed_if (output_warnings (errorKey2), "warnings in kdbOpen");
 	succeed_if (output_error (errorKey2), "errors in kdbOpen");
 	exit_if_fail (plugin2 != NULL, "unable to load python plugin again");
@@ -105,7 +108,7 @@ static void test_fail ()
 
 	KeySet * conf = ksNew (2, keyNew ("user/script", KEY_VALUE, python_file ("python_plugin_fail.py"), KEY_END),
 			       keyNew ("user/shutdown", KEY_VALUE, "1", KEY_END), keyNew ("user/print", KEY_END), KS_END);
-	PLUGIN_OPEN (PYTHON_PLUGIN_NAME);
+	PLUGIN_OPEN (STRINGIFY (PYTHON_PLUGIN_NAME));
 
 	Key * parentKey = keyNew ("user/tests/from_c", KEY_END);
 	KeySet * ks = ksNew (0, KS_END);
@@ -132,7 +135,7 @@ static void test_wrong ()
 			       keyNew ("user/shutdown", KEY_VALUE, "1", KEY_END), keyNew ("user/print", KEY_END), KS_END);
 
 	Key * errorKey = keyNew ("", KEY_END);
-	Plugin * plugin = elektraPluginOpen (PYTHON_PLUGIN_NAME, modules, conf, errorKey);
+	Plugin * plugin = elektraPluginOpen (STRINGIFY (PYTHON_PLUGIN_NAME), modules, conf, errorKey);
 	succeed_if (!output_warnings (errorKey), "we expect some warnings");
 	succeed_if (!output_error (errorKey), "we expect some errors");
 	succeed_if (plugin == NULL, "python plugin shouldn't be loadable");
