@@ -583,356 +583,6 @@ static int handleErrors (Key * parentKey, KeySet * ks, Key * key, Key * specKey,
 	return ret;
 }
 
-
-// Naive approach to replace wildcards in meta string with the actual values
-
-static void matchedKeyCopyMeta (Key * key, Key * specKey, Key * parentKey, const char * name)
-{
-	Key * metaKey = (Key *)keyGetMeta (specKey, name);
-	const char * metaString = keyString (metaKey);
-
-	// name relative to parent key
-	size_t offset = 1;
-	if (strchr (keyName (parentKey), '/') != NULL) offset += strlen ((strchr (keyName (parentKey), '/')));
-
-	const char * relativeName = strchr (keyName (specKey), '/') + offset;
-
-	int hasWildcard = 0;
-	int singleWC = 0;
-	int multiWC = 0;
-	int arrayWC = 0;
-	int metaHasWildcard = 0;
-	char * ptr = (char *)relativeName;
-
-	// Counting occurrences of ?, _ and # in spec keyname
-	while (*ptr)
-	{
-		if (*ptr == '?')
-		{
-			++singleWC;
-		}
-		else if (*ptr == '_')
-		{
-			++multiWC;
-		}
-		else if (*ptr == '#')
-		{
-			++arrayWC;
-		}
-		++ptr;
-	}
-	hasWildcard = singleWC + multiWC + arrayWC;
-
-	// check if metastring has wildcards
-	if (hasWildcard)
-	{
-		ptr = (char *)metaString;
-		while (*ptr)
-		{
-			if (*ptr == '?' || *ptr == '_' || *ptr == '#') ++metaHasWildcard;
-			++ptr;
-		}
-	}
-
-	// both keyname and string have wildcards
-	if (metaHasWildcard && hasWildcard)
-	{
-		// keyname with wildcards matched to actual values relative to parent key
-		const char * relativeFullName = strchr (keyName (key), '/') + strlen (strchr (keyName (parentKey), '/')) + 1;
-
-		size_t newMetaSize = keyGetValueSize (metaKey) + 3 * (strlen (relativeFullName) - strlen (relativeName));
-		char * newMetaString = elektraCalloc (newMetaSize);
-		char * src = (char *)metaString;
-		char * dest = newMetaString;
-		int singleWCCounter = 0;
-		int multiWCCounter = 0;
-		int arrayWCCounter = 0;
-
-		// search and replace wildcards using the same order the globbing key has module the number of occurrences.
-		while (*src)
-		{
-			if (*src != '?' && *src != '_' && *src != '#')
-			{
-				*dest = *src;
-				++src;
-				++dest;
-			}
-			else
-			{
-				// found a wildcard
-
-				char * segmentStart = src;
-				char * segmentEnd = src;
-				int localCounter = 0;
-				ptr = (char *)relativeName;
-
-				// try to find the corresponding wildcard in the globbing key.
-				if (*src == '?' && singleWC)
-				{
-					++singleWCCounter;
-					if (singleWCCounter > singleWC) singleWCCounter = 1;
-					while (localCounter < singleWCCounter)
-					{
-						if (*ptr == '?') ++localCounter;
-						++ptr;
-					}
-				}
-				else if (*src == '_' && multiWC)
-				{
-					++multiWCCounter;
-					if (multiWCCounter > multiWC) multiWCCounter = 1;
-					while (localCounter < multiWCCounter)
-					{
-						if (*ptr == '_') ++localCounter;
-						++ptr;
-					}
-				}
-				else if (*src == '#' && arrayWC)
-				{
-					++arrayWCCounter;
-					if (arrayWCCounter > arrayWC) arrayWCCounter = 1;
-					while (localCounter < arrayWCCounter)
-					{
-						if (*ptr == '#') ++localCounter;
-						++ptr;
-					}
-				}
-				--ptr;
-				int noMatch = 0;
-				char * ptrCopy = ptr;
-
-				// check if the key name part containing the wildcard matches the globbing key
-
-				// check starting at the wildcard until the start of the name part.
-				while (!noMatch && ptrCopy > relativeName && segmentStart > metaString)
-				{
-					if (*ptrCopy == '?')
-					{
-						while (*segmentStart != '/' && segmentStart > metaString && ptrCopy > relativeName &&
-						       *ptrCopy != '/')
-						{
-							--segmentStart;
-							--ptrCopy;
-							if (*segmentStart != *ptrCopy)
-							{
-								noMatch = 1;
-								break;
-							}
-						}
-						if (*segmentStart == *ptrCopy && *ptrCopy != '\0')
-						{
-							segmentStart = src;
-							break;
-						}
-					}
-					else if (*ptrCopy == '_')
-					{
-						while (*segmentStart != '/' && segmentStart > metaString && ptrCopy > relativeName &&
-						       *ptrCopy != '/')
-						{
-							--segmentStart;
-							--ptrCopy;
-							if (*segmentStart != *ptrCopy)
-							{
-								noMatch = 1;
-								break;
-							}
-						}
-						if (*segmentStart == *ptrCopy && *ptrCopy != '\0')
-						{
-							segmentStart = src;
-							break;
-						}
-					}
-					else if (*ptrCopy == '#')
-					{
-						--segmentStart;
-						--ptrCopy;
-						if (*segmentStart != *ptrCopy)
-						{
-							noMatch = 1;
-							break;
-						}
-						if (*segmentStart == *ptrCopy && *ptrCopy != '\0')
-						{
-							segmentStart = src;
-							break;
-						}
-					}
-					else if (*ptrCopy != *segmentStart)
-					{
-						noMatch = 1;
-						break;
-					}
-				}
-				ptrCopy = ptr;
-
-				// check from wildcard position until the end of the key name part is found
-				while ((!noMatch) && (ptrCopy < relativeName + strlen (relativeName)) &&
-				       (segmentEnd < metaString + strlen (metaString)))
-				{
-					if (*ptrCopy == '?')
-					{
-						while (*segmentEnd != '/' && segmentEnd < metaString + strlen (metaString) &&
-						       ptrCopy < relativeName + strlen (relativeName) && *ptrCopy != '/')
-						{
-							++segmentEnd;
-							++ptrCopy;
-							if (*segmentEnd != *ptrCopy)
-							{
-								noMatch = 1;
-								break;
-							}
-						}
-						if (*segmentEnd == *ptrCopy && *ptrCopy != '\0') break;
-					}
-					else if (*ptrCopy == '_')
-					{
-						while (*segmentEnd != '/' && segmentEnd < metaString + strlen (metaString) &&
-						       ptrCopy < relativeName + strlen (relativeName) && *ptrCopy != '/')
-						{
-							++segmentEnd;
-							++ptrCopy;
-							if (*segmentEnd != *ptrCopy)
-							{
-								noMatch = 1;
-								break;
-							}
-						}
-						if (*segmentEnd == *ptrCopy && *ptrCopy != '\0')
-						{
-							break;
-						}
-					}
-					else if (*ptrCopy == '#')
-					{
-						++segmentEnd;
-						++ptrCopy;
-						if (*segmentEnd != *ptrCopy)
-						{
-							noMatch = 1;
-							break;
-						}
-						if (*segmentEnd == *ptrCopy && *ptrCopy != '\0')
-						{
-							break;
-						}
-					}
-					else if (*ptrCopy != *segmentEnd)
-					{
-						noMatch = 1;
-						break;
-					}
-				}
-
-				segmentEnd = ptrCopy;
-
-				if (!noMatch)
-				{
-					// key name part in string matches the globbing key name part
-
-					char * realPtr = (char *)relativeFullName;
-					char * otherPtr = (char *)relativeName;
-					int localSingleWCCounter = 0;
-					int localMultiWCCounter = 0;
-					int localArrayWCCounter = 0;
-
-					// replace wildcard with actual match.
-					while (*otherPtr)
-					{
-						if (*otherPtr == '?' && *src == '?')
-						{
-							++localSingleWCCounter;
-							if (localSingleWCCounter == singleWCCounter) break;
-							++realPtr;
-							++otherPtr;
-						}
-						else if (*otherPtr == '_' && *src == '_')
-						{
-							++localMultiWCCounter;
-							if (localMultiWCCounter == multiWCCounter) break;
-							++otherPtr;
-							while (*realPtr && *realPtr != *otherPtr)
-							{
-								++realPtr;
-							}
-						}
-						else if (*otherPtr == '#' && *src == '#')
-						{
-							++localArrayWCCounter;
-							if (localArrayWCCounter == arrayWCCounter) break;
-							++otherPtr;
-							while (*realPtr && *realPtr != *otherPtr)
-							{
-								++realPtr;
-							}
-						}
-						else if (*otherPtr == '?' && *realPtr != '?')
-						{
-							++otherPtr;
-							++realPtr;
-						}
-						else if (*otherPtr == '_' && *realPtr != '_')
-						{
-							++otherPtr;
-							while (*realPtr && *realPtr != *otherPtr)
-								++realPtr;
-						}
-						else if (*otherPtr == '#' && *realPtr != '#')
-						{
-							++otherPtr;
-							while (*realPtr && *realPtr != *otherPtr)
-								++realPtr;
-						}
-						else if (*otherPtr == *realPtr)
-						{
-							++otherPtr;
-							++realPtr;
-						}
-					}
-					while (*realPtr && *realPtr != *segmentEnd)
-					{
-						*dest = *realPtr;
-						++dest;
-						++realPtr;
-					}
-					++src;
-				}
-				else
-				{
-					// doesn't match globbing part,
-					// since it's not an actual wildcard, decrement the counter again.
-					// move on to the next symbol.
-
-					if (*src == '#')
-					{
-						--multiWCCounter;
-					}
-					else if (*src == '?')
-					{
-						--singleWCCounter;
-					}
-					else if (*src == '#')
-					{
-						--arrayWCCounter;
-					}
-					*dest = *src;
-					++dest;
-					++src;
-				}
-			}
-		}
-		keySetMeta (key, name, newMetaString);
-		elektraFree (newMetaString);
-	}
-	else
-	{
-		// no wildcards in string, simply copy the metadata
-
-		keyCopyMeta (key, specKey, name);
-	}
-}
-
 static void removeMeta (Key * key, Key * specKey, Key * parentKey ELEKTRA_UNUSED)
 {
 	keyRewindMeta (specKey);
@@ -952,7 +602,7 @@ static void removeMeta (Key * key, Key * specKey, Key * parentKey ELEKTRA_UNUSED
 	}
 }
 
-static void copyMeta (Key * key, Key * specKey, Key * parentKey)
+static void copyMeta (Key * key, Key * specKey, Key * parentKey ELEKTRA_UNUSED)
 {
 	keyRewindMeta (specKey);
 	while (keyNextMeta (specKey) != NULL)
@@ -971,14 +621,14 @@ static void copyMeta (Key * key, Key * specKey, Key * parentKey)
 					char * conflictName = elektraMalloc (conflictStringSize);
 					snprintf (conflictName, conflictStringSize, "conflict/%s", name);
 					keySetMeta (key, conflictName, keyString (oldMeta));
-					matchedKeyCopyMeta (key, specKey, parentKey, name);
+					keyCopyMeta (key, specKey, name);
 					elektraFree (conflictName);
 					elektraMetaArrayAdd (key, "conflict/collision", name);
 				}
 			}
 			else
 			{
-				matchedKeyCopyMeta (key, specKey, parentKey, name);
+				keySetMeta (key, name, keyString (meta));
 			}
 		}
 	}
@@ -1081,7 +731,7 @@ static int doGlobbing (Key * parentKey, KeySet * returned, KeySet * specKS, Conf
 			if (keyGetMeta (specKey, "assign/condition")) // hardcoded for now because only assign/conditional currently exists
 			{
 				Key * newKey = keyNew (strchr (keyName (specKey), '/'), KEY_CASCADING_NAME, KEY_END);
-				copyMeta (newKey, specKey, parentKey);
+				keySetMeta (newKey, "assign/condition", keyString (keyGetMeta (specKey, "assign/condition")));
 				ksAppendKey (returned, keyDup (newKey));
 				keyDel (newKey);
 			}
@@ -1224,7 +874,6 @@ int elektraSpecSet (Plugin * handle, KeySet * returned, Key * parentKey)
 	KeySet * config = elektraPluginGetConfig (handle);
 	Key * onConflictConf = ksLookupByName (config, "/conflict/set", KDB_O_NONE);
 	OnConflict onConflict = IGNORE;
-	ConflictHandling * ch = elektraMalloc (sizeof (ConflictHandling));
 	if (onConflictConf)
 	{
 		const char * onConflictString = keyName (onConflictConf);
@@ -1256,6 +905,7 @@ int elektraSpecSet (Plugin * handle, KeySet * returned, Key * parentKey)
 		clean = 1;
 		pluginConfig->counter = 0;
 	}
+	ConflictHandling * ch = elektraMalloc (sizeof (ConflictHandling));
 	ch->member = onConflict;
 	ch->invalid = onConflict;
 	ch->count = onConflict;
