@@ -24,39 +24,38 @@
 #include "iterator.h"
 #include "name.h"
 
-typedef enum
-{
+typedef enum {
 	/**
 	 * We are at end of string, so no lookahead.
 	 */
-	LOOKAHEAD_END=0,
+	LOOKAHEAD_END = 0,
 	/**
 	 * We are iterating in the middle of an array (or at least
 	 * certainly not starting it)
 	 */
-	LOOKAHEAD_ARRAY=1,
+	LOOKAHEAD_ARRAY = 1,
 	/**
 	 * We found a special marker for empty arrays.
 	 * @todo not implemented yet
 	 */
-	LOOKAHEAD_EMPTY_ARRAY=3,
+	LOOKAHEAD_EMPTY_ARRAY = 3,
 	/**
 	 * We found a special marker for empty maps.
 	 * @todo not implemented yet
 	 */
-	LOOKAHEAD_EMPTY_MAP=4,
+	LOOKAHEAD_EMPTY_MAP = 4,
 	/**
 	 * We are iterating a map or starting it.
 	 */
-	LOOKAHEAD_MAP=5
+	LOOKAHEAD_MAP = 5
 } lookahead_t;
 
-lookahead_t elektraLookahead(const char* pnext, size_t size);
+lookahead_t elektraLookahead (const char * pnext, size_t size);
 
-void elektraGenOpenInitial(yajl_gen g, Key *parentKey, const Key *first);
-void elektraGenOpen(yajl_gen g, const Key *cur, const Key *next);
+void elektraGenOpenInitial (yajl_gen g, Key * parentKey, const Key * first);
+void elektraGenOpen (yajl_gen g, const Key * cur, const Key * next);
 
-void elektraGenClose(yajl_gen g, const Key *cur, const Key *next);
-void elektraGenCloseFinally(yajl_gen g, const Key *cur, const Key *next);
+void elektraGenClose (yajl_gen g, const Key * cur, const Key * next);
+void elektraGenCloseFinally (yajl_gen g, const Key * cur, const Key * next);
 
 #endif
