@@ -1,6 +1,7 @@
 #ifndef EDITOR_HPP
 #define EDITOR_HPP
 
+#include "coloredkdbio.hpp"
 #include <command.hpp>
 #include <kdb.hpp>
 
@@ -20,7 +21,7 @@ public:
 
 	virtual std::string getShortOptions ()
 	{
-		return "esv";
+		return "esvC";
 	}
 
 	virtual std::string getSynopsis ()
