@@ -453,7 +453,10 @@ void TreeViewModel::sink (ConfigNodePtr node, QStringList keys, const Key & key)
 	{
 		if (node->getChildByName (name)->getKey () && node->getChildByName (name)->getKey ().getName () == key.getName ())
 		{
-			node->getChildByName (name)->updateNode (key);
+			if (node->getChildByName (name)->getKey ().getName () == key.getName ())
+			{
+				node->getChildByName (name)->updateNode (key);
+			}
 		}
 
 		sink (node->getChildByName (name), keys, key);
@@ -647,12 +650,6 @@ void TreeViewModel::synchronize ()
 	}
 	catch (MergingKDBException const & exc)
 	{
-
-#if DEBUG && VERBOSE
-		std::cout << "guitest: exception: now after set" << std::endl;
-		printKeys (theirs, result, ours);
-#endif
-
 		QStringList conflicts = getConflicts (exc.getConflicts ());
 		emit showMessage (tr ("Error"), tr ("Synchronizing failed, conflicts occured."), conflicts.join ("\n"));
 	}
