@@ -15,13 +15,13 @@ ROOT_FILE=${FILE_SUFFIX}_root.ecf
 ROOT_MOUNTPOINT=/test/script
 if is_plugin_available dump
 then
-	$KDB mount $ROOT_FILE $ROOT_MOUNTPOINT dump > /dev/null 2>&1
+	"$KDB" mount $ROOT_FILE $ROOT_MOUNTPOINT dump > /dev/null 2>&1
 	succeed_if "could not mount root: $ROOT_FILE at $ROOT_MOUNTPOINT"
 
-	$KDB set $ROOT/valueable_data important_unrecoverable_data > /dev/null
+	"$KDB" set $ROOT/valueable_data important_unrecoverable_data > /dev/null
 	succeed_if "cannot set valueable data"
 
-	$KDB setmeta $ROOT/valueable_data trigger/error 10
+	"$KDB" setmeta $ROOT/valueable_data trigger/error 10
 	succeed_if "cannot set meta data"
 fi
 
@@ -43,11 +43,11 @@ if is_plugin_available error
 then
 	echo "Testing operations on errornous backends"
 
-	$KDB mount $ERROR_FILE $ERROR_MOUNTPOINT dump error > /dev/null 2>&1
+	"$KDB" mount $ERROR_FILE $ERROR_MOUNTPOINT dump error > /dev/null 2>&1
 	succeed_if "could not mount error at $ERROR_MOUNTPOINT"
 
 
-	$KDB mv $ROOT/valueable_data $ROOT/error/dump > $TMPFILE 2>&1
+	"$KDB" mv $ROOT/valueable_data $ROOT/error/dump > $TMPFILE 2>&1
 	[ $? -ne 0 ]
 	succeed_if "Was able to move to error plugin"
 
@@ -57,14 +57,14 @@ then
 	grep "Reason: from error plugin" $TMPFILE > /dev/null
 	succeed_if "Error does not stem from error plugin"
 
-	[ "x`$KDB ls $ROOT 2> /dev/null`" = "x$ROOT/valueable_data" ]
+	[ "x`"$KDB" ls $ROOT 2> /dev/null`" = "x$ROOT/valueable_data" ]
 	succeed_if "cant ls $ROOT (may mean that $ROOT folder is not clean)"
 
-	[ "x`$KDB get $ROOT/valueable_data 2> /dev/null`" = "ximportant_unrecoverable_data" ]
+	[ "x`"$KDB" get $ROOT/valueable_data 2> /dev/null`" = "ximportant_unrecoverable_data" ]
 	succeed_if "Important data lost"
 
 
-	$KDB cp $ROOT/valueable_data $ROOT/error/dump > $TMPFILE 2>&1
+	"$KDB" cp $ROOT/valueable_data $ROOT/error/dump > $TMPFILE 2>&1
 	[ $? -ne 0 ]
 	succeed_if "Was able to copy to error plugin"
 
@@ -74,13 +74,13 @@ then
 	grep "Reason: from error plugin" $TMPFILE > /dev/null
 	succeed_if "Error does not stem from error plugin"
 
-	[ "x`$KDB ls $ROOT 2> /dev/null`" = "x$ROOT/valueable_data" ]
+	[ "x`"$KDB" ls $ROOT 2> /dev/null`" = "x$ROOT/valueable_data" ]
 	succeed_if "cant ls $ROOT (may mean that $ROOT folder is not clean)"
 
-	[ "x`$KDB get $ROOT/valueable_data 2> /dev/null`" = "ximportant_unrecoverable_data" ]
+	[ "x`"$KDB" get $ROOT/valueable_data 2> /dev/null`" = "ximportant_unrecoverable_data" ]
 	succeed_if "data would have been lost"
 
-	$KDB umount $ERROR_MOUNTPOINT >/dev/null
+	"$KDB" umount $ERROR_MOUNTPOINT >/dev/null
 	succeed_if "could not umount $ERROR_MOUNTPOINT"
 
 
@@ -127,7 +127,7 @@ rm $TMPFILE
 
 if is_plugin_available dump
 then
-	$KDB umount $ROOT_MOUNTPOINT >/dev/null
+	"$KDB" umount $ROOT_MOUNTPOINT >/dev/null
 	succeed_if "could not umount $ROOT_MOUNTPOINT"
 fi
 
